.. _api_geometry_rectangle:

.. currentmodule:: microstructpy.geometry

microstructpy.geometry.Rectangle
================================

.. autoclass:: Rectangle
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: